[![codecov](https://codecov.io/gh/the-cyber-boardroom/cbr-website-beta/graph/badge.svg?token=NZDJOJ2CYH)](https://codecov.io/gh/the-cyber-boardroom/cbr-website-beta)
![Current Release](https://img.shields.io/badge/release-v0.77.3-blue)

# CBR Website - Beta

Main repo for The Cyber Boardroom website deployed in a serverless AWS environment (i.e. using Lambdas)


## Coverage details

Here is the [CodeCov page](https://app.codecov.io/gh/the-cyber-boardroom/cbr-website-beta) for this repo

![](https://codecov.io/gh/the-cyber-boardroom/cbr-website-beta/graphs/sunburst.svg?token=NZDJOJ2CYH)
![](https://codecov.io/gh/the-cyber-boardroom/cbr-website-beta/graphs/tree.svg?token=NZDJOJ2CYH)
![](https://codecov.io/gh/the-cyber-boardroom/cbr-website-beta/graphs/icicle.svg?token=NZDJOJ2CYH)